==> Statemate4.6.1.4Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Statemate/wwhdata/js/search/pairs/pair47.js <==
function FileData_Pairs(x)
{
x.t("supports","interactive");
x.t("time-","consuming");
x.t("deleting","unused");
x.t("improve","workflow");
x.t("performs","clean-up");
x.t("working","environment");
x.t("necessary","definitions");
x.t("collects","automatically");
x.t("deletes","following");
x.t("automatically","deletes");
x.t("automatically","charts");
x.t("items","thus");
x.t("size","workarea");
x.t("check","outs");
x.t("workareas","reducing");
x.t("eliminate","unnecessary");
x.t("operation","performs");
x.t("operation","collects");
x.t("eliminates","time-");
x.t("reduced","gds");
x.t("selection","eliminates");
x.t("charts","view");
x.t("charts","filtered");
x.t("allowing","users");
x.t("interactive","work");
x.t("workarea","improve");
x.t("workarea","working");
x.t("workarea","automatically");
x.t("workarea","operation");
x.t("workarea","feature");
x.t("workarea","unused");
x.t("workarea","reduce");
x.t("workarea","reducing");
x.t("feature","supports");
x.t("feature","feature");
x.t("unused","elements");
x.t("select","configuration");
x.t("clean-up","selection");
x.t("activity","charts");
x.t("workflow","dealing");
x.t("may","quickly");
x.t("reduce","size");
x.t("reduce","charts");
x.t("reduce","workarea");
x.t("reduce","definitions");
x.t("dealing","reduce");
x.t("thus","reduce");
x.t("environment","workareas");
x.t("quickly","eliminate");
x.t("configuration","reduce");
x.t("process","deleting");
x.t("view","select");
x.t("read","reduced");
x.t("(read-only)","activity");
x.t("reducing","workarea");
x.t("users","work");
x.t("gds","elements");
x.t("outs","may");
x.t("work","allowing");
x.t("work","minimal");
x.t("elements","read");
x.t("elements","(read-only)");
x.t("elements","manually");
x.t("following","workarea");
x.t("minimal","necessary");
x.t("manually","reduce");
x.t("unnecessary","items");
x.t("definitions","workarea");
x.t("definitions","reduce");
x.t("filtered","check");
x.t("consuming","process");
}

==> Statemate4.6.1.10Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Using Statemate/wwhdata/js/search/pairs/pair47.js <==
function FileData_Pairs(x)
{
x.t("supports","interactive");
x.t("deleting","unused");
x.t("improve","workflow");
x.t("performs","clean-up");
x.t("working","environment");
x.t("necessary","definitions");
x.t("collects","automatically");
x.t("deletes","following");
x.t("automatically","deletes");
x.t("automatically","charts");
x.t("items","thus");
x.t("size","workarea");
x.t("check","outs");
x.t("workareas","reducing");
x.t("time-consuming","process");
x.t("eliminate","unnecessary");
x.t("operation","performs");
x.t("operation","collects");
x.t("eliminates","time-consuming");
x.t("reduced","gds");
x.t("selection","eliminates");
x.t("charts","view");
x.t("charts","filtered");
x.t("allowing","users");
x.t("interactive","work");
x.t("workarea","improve");
x.t("workarea","working");
x.t("workarea","automatically");
x.t("workarea","operation");
x.t("workarea","feature");
x.t("workarea","unused");
x.t("workarea","reduce");
x.t("workarea","reducing");
x.t("feature","supports");
x.t("feature","feature");
x.t("unused","elements");
x.t("select","configuration");
x.t("clean-up","selection");
x.t("activity","charts");
x.t("workflow","dealing");
x.t("may","quickly");
x.t("reduce","size");
x.t("reduce","charts");
x.t("reduce","workarea");
x.t("reduce","definitions");
x.t("dealing","reduce");
x.t("thus","reduce");
x.t("environment","workareas");
x.t("quickly","eliminate");
x.t("configuration","reduce");
x.t("process","deleting");
x.t("view","select");
x.t("read","reduced");
x.t("(read-only)","activity");
x.t("reducing","workarea");
x.t("users","work");
x.t("gds","elements");
x.t("outs","may");
x.t("work","allowing");
x.t("work","minimal");
x.t("elements","read");
x.t("elements","(read-only)");
x.t("elements","manually");
x.t("following","workarea");
x.t("minimal","necessary");
x.t("manually","reduce");
x.t("unnecessary","items");
x.t("definitions","workarea");
x.t("definitions","reduce");
x.t("filtered","check");
}
